@@ -1,12 +1,12 @@
-import supabase
 from embedbase import get_app
 from embedbase.settings import get_settings
+from embedbase.supabase_db import Supabase
 
 settings = get_settings()
 app = (
     get_app(settings)
     .use(
-        supabase.client.Client(
+        Supabase(
             settings.supabase_url,
             settings.supabase_key,
         )
